package com.lz.modules.flow.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.lz.common.utils.R;
import com.lz.modules.flow.entity.ResultModel;
import com.lz.modules.flow.entity.ResultTagetLib;
import com.lz.modules.flow.model.ResultModelDto;
import com.lz.modules.flow.req.ResultModelDetailReq;

import java.util.List;

/**
* <p>
* 考核模板表 服务类
* </p>
*
* @author quyixiao
* @since 2020-10-13
*/
public interface ResultModelService extends IService<ResultModel> {



	ResultModel selectResultModelById(Long id);


	Long insertResultModel(ResultModel resultModel);


	int updateResultModelById(ResultModel resultModel);


	int updateCoverResultModelById(ResultModel resultModel);


	R deleteResultModelById(Long id);


    List<ResultModel> selectResultModelByGroupId(Long id);

    List<ResultModelDto> selectResultDtoByGroupId(Long id);

	R deleteResultModelByGroupId(Long id);

    R saveDetail(ResultModelDetailReq resultModelDetailReq);
}